@@ -625,6 +625,15 @@ append_titles( fields *in, int type, fields *out, int format_opts, int *status )
 		*status = append_title( in, "series", 1, out, format_opts );
 		if ( *status!=BIBL_OK ) return;
 		*status = append_title( in, "series", 2, out, format_opts );
+
+		// // (2020-12-27) added by Georgi
+		// // TODO: not sure about this it always sets booktitle same as title.
+		// //      Logical but iridia uses booktitle for abbreviated title
+		// //      this looks like iridia convention; COMMENTING OUT
+		// //
+		// if ( *status!=BIBL_OK ) return;
+		// *status = append_title( in, "booktitle", LEVEL_ANY, out, format_opts );
+
 		break;
 
 		default:
@@ -893,11 +902,48 @@ append_howpublished( fields *in, fields *out, int *status )
 	}
 }
 
+// Georgi
+static void
+append_key( fields *in, char *intag, char *outtag, fields *out, int *status )
+{
+        int n, fstatus;
+        
+        char *tag, *value;
+        str data;
+        
+        str_init( &data );
+        
+        n = fields_find( in, intag, LEVEL_ANY );
+        if ( n!=FIELDS_NOTFOUND ) {
+            fields_set_used( in, n );
+            
+            value = fields_value( in, n, FIELDS_CHRP );
+	    str_strcatc( &data, "c(" );
+            str_strcatc( &data, "key = \"" );
+            str_strcatc( &data, value );
+            str_strcatc( &data, "\")" );
+                
+            // fstatus = fields_add( out, outtag, str_cstr( &data ), LEVEL_MAIN );
+            fstatus = fields_add( out, outtag, data.data, LEVEL_MAIN );
+            if ( fstatus!=FIELDS_OK ) {
+                *status = BIBL_ERR_MEMERR;
+                goto out;
+            }
+        }
+
+out:
+	str_free( &data );
+
+}
+
 static int
 bibentryout_assemble( fields *in, fields *out, param *pm, unsigned long refnum )
 {
 	int type, status = BIBL_OK;
 
+	// Georgi; for testing
+	// fields_report_stderr(in);
+
 	type = bibentryout_type( in, pm->progname, "", refnum );
 
 	append_type        ( type, out, &status );
@@ -943,6 +989,9 @@ bibentryout_assemble( fields *in, fields *out, param *pm, unsigned long refnum )
 	append_howpublished( in, out, &status );
 
 	append_simple      ( in, "CHAPTER",           "chapter",  out, &status ); // Georgi
+	// Georgi - some entries may have field 'key' (it is used by some bibtex styles)
+        //       other = c(key = "mykey")
+	append_key      ( in, "KEY",   "other"        ,  out, &status );
 
 	return status;
 }
